cosmpy.protos.cosmwasm.wasm.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmwasm.wasm.v1beta1 package

## Submodules

## cosmpy.protos.cosmwasm.wasm.v1beta1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmwasm.wasm.v1beta1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmwasm.wasm.v1beta1.ibc_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmwasm.wasm.v1beta1.ibc_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmwasm.wasm.v1beta1.proposal_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmwasm.wasm.v1beta1.proposal_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmwasm.wasm.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmwasm.wasm.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmwasm.wasm.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query provides defines the gRPC querier service

  static AllContractState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Code(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Codes(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ContractHistory(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ContractInfo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ContractsByCode(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static RawContractState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static SmartContractState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmwasm.wasm.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query provides defines the gRPC querier service

  AllContractState(request, context)

    AllContractState gets all raw store data for a single contract

  Code(request, context)

    Code gets the binary code and metadata for a singe wasm code

  Codes(request, context)

    Codes gets the metadata for all stored wasm codes

  ContractHistory(request, context)

    ContractHistory gets the contract code history

  ContractInfo(request, context)

    ContractInfo gets the contract meta data

  ContractsByCode(request, context)

    ContractsByCode lists all smart contracts for a code id

  RawContractState(request, context)

    RawContractState gets single key from the raw store data of a contract

  SmartContractState(request, context)

    SmartContractState get smart query result from the contract

class cosmpy.protos.cosmwasm.wasm.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query provides defines the gRPC querier service

cosmpy.protos.cosmwasm.wasm.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.cosmwasm.wasm.v1beta1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmwasm.wasm.v1beta1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmwasm.wasm.v1beta1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the wasm Msg service.

  static ClearAdmin(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ExecuteContract(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static InstantiateContract(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static MigrateContract(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static StoreCode(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static UpdateAdmin(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmwasm.wasm.v1beta1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the wasm Msg service.

  ClearAdmin(request, context)

    ClearAdmin removes any admin stored for a smart contract

  ExecuteContract(request, context)

    Execute submits the given message data to a smart contract

  InstantiateContract(request, context)

    Instantiate creates a new smart contract instance for the given code id.

  MigrateContract(request, context)

    Migrate runs a code upgrade/ downgrade for a smart contract

  StoreCode(request, context)

    StoreCode to submit Wasm code to the system

  UpdateAdmin(request, context)

    UpdateAdmin sets a new admin for a smart contract

class cosmpy.protos.cosmwasm.wasm.v1beta1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the wasm Msg service.

cosmpy.protos.cosmwasm.wasm.v1beta1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## cosmpy.protos.cosmwasm.wasm.v1beta1.types_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmwasm.wasm.v1beta1.types_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## Module contents